<template>
  <div class="lineChart-container" ref="lineChart"></div>
</template>

<script>

export default {
  name: 'lineChart',
  props: {
    workOrderRegion: {
      type: Array,
      default: null,
    },
  },
  data() {
    return {
      name: [],
      data1: [],
      data2: [],

      myDrawLine: null
    }
  },

  methods: {
    setFontSize(res){
      const clientWidth = window.innerWidth||document.documentElement.clientWidth||document.body.clientWidth;
      if (!clientWidth) return;
      let fontSize = clientWidth / 1920;
      return res*fontSize;
    },
    initDrawLine() {
      const that = this
      let option = {
        grid: {
          left: '15%',
          right: '5%'
        },
        tooltip: {
          trigger: 'item',
          formatter: function (params) {
            let str = '<div><p>' + params.name + '</p></div>'
            str += params.marker + params.seriesName + '：' + params.data
            return str
          },
          textStyle: {
            fontSize: this.setFontSize(16)
          }
        },

        // 图例组件
        legend: {
          type: 'plain',
          top: 20,
          data: ['已处理工单数', '未处理工单数'],
          textStyle: {
            color: '#A0AEC0',
            fontSize: this.setFontSize(14)
          }
        },

        // X轴配置
        xAxis: {
          type: 'category',
          boundaryGap: false,
          axisTick: {
            show: true
          },
          axisLine: {
            lineStyle: {
              color: '#A0AEC0',
              type: 'solid'
            }
          },
          axisLabel: {
            color: '#A0AEC0',
            fontSize: this.setFontSize(14),
            margin: 20,
            rotate: 30
          },
          data: that.name,
        },
        // Y轴配置
        yAxis: {
          type: 'value',
          splitLine: {
            lineStyle: {
              color: '#A0AEC0',
              type: 'dashed'
            }
          },
          splitNumber: 5,
          axisLine: {
            show: false
          },
          axisLabel: {
            color: '#A0AEC0',
            fontSize: this.setFontSize(14),
            margin: 5
          }
        },
        // 系列列表（多个折线图）
        series: [
          {
            name: '已处理工单数',
            type: 'line',
            data: that.data1,
            smooth: true,
            areaStyle: {
              color: new this.$echarts.graphic.LinearGradient(0, 0, 0, 1, [
                {offset: 0, color: '#00a2ff'},
                {offset: 0.5, color: 'rgba(0,162,255,0.1)'},
                {offset: 1, color: 'rgba(0,162,255,0.1)'}
              ])
            },

            lineStyle: {
              color: '#00a2ff',
              width: 1
            },
            itemStyle: {
              color: '#00a2ff'
            }
          },
          {
            name: '未处理工单数',
            type: 'line',
            data: that.data2,
            smooth: true,
            areaStyle: {
              color: new this.$echarts.graphic.LinearGradient(0, 0, 0, 1, [
                {offset: 0, color: '#e4b54f'},
                {offset: 0.5, color: 'rgba(228,181,79,0.1)'},
                {offset: 1, color: 'rgba(228,181,79,0.1)'}
              ])
            },

            lineStyle: {
              color: '#e4b54f',
              width: 1
            },
            itemStyle: {
              color: '#e4b54f'
            }
          }
        ]
      }

      that.myDrawLine = this.$echarts.init(this.$refs.lineChart)
      that.myDrawLine.setOption(option)
      window.addEventListener('resize', function () {
        that.myDrawLine.resize()
      })
    }
  },

  watch: {
    workOrderRegion: {
      handler(newV, oldV) {
        this.name = []
        this.data1 = []
        this.data2 = []
        newV.map((item) => {
          this.name.push(item.area);
          this.data1.push(item.doneNum);
          this.data2.push(item.todoNum);
        })
        this.initDrawLine()
      },
      deep: true
    }
  },
  mounted() {
    this.$nextTick(() => {
      setTimeout(() => {
        this.initDrawLine()
      }, 100)
    })
  }
}
</script>

<style lang="scss" scoped>
.lineChart-container {
  width: 100%;
  height: 100%;
}
</style>
